==> 4.1.4.zip: madelineproto/src/danog/MadelineProto/Loop/Generic/PeriodicLoop.php <==
<?php
/**
 * Periodic loop.
 *
 * This file is part of MadelineProto.
 * MadelineProto is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * MadelineProto is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU General Public License along with MadelineProto.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * @author    Daniil Gentili <daniil@daniil.it>
 * @copyright 2016-2019 Daniil Gentili <daniil@daniil.it>
 * @license   https://opensource.org/licenses/AGPL-3.0 AGPLv3
 *
 * @link      https://docs.madelineproto.xyz MadelineProto documentation
 */

namespace danog\MadelineProto\Loop\Generic;

use danog\MadelineProto\Loop\Impl\ResumableSignalLoop;

/**
 * Periodic loop.
 *
 * @author Daniil Gentili <daniil@daniil.it>
 */
class PeriodicLoop extends ResumableSignalLoop
{
    private $callback;
    private $name;
    private $timeout;
    
    /**
     * Constructor.
     *
     *
     * @param \danog\MadelineProto\MTProto $API      Instance of MTProto class
     */
    public function __construct($API, $callback, $name, $timeout)
    {
        $this->API = $API;
        $this->callback = $callback;
        $this->name = $name;
        $this->timeout = $timeout;
    }

    public function loop()
    {
        $callback = $this->callback;
        $logger = $this->API->logger;

        while (true) {
            $result = yield $this->waitSignal($this->pause($this->timeout));
            if ($result) {
                $logger->logger("Got signal in $this, exiting");
                return;
            }
            yield $callback();
        }
    }

    public function __toString(): string
    {
        return $this->name;
    }
}

==> 4.2.2.zip: madelineproto/src/danog/MadelineProto/Loop/Generic/PeriodicLoop.php <==
<?php
/**
 * Periodic loop.
 *
 * This file is part of MadelineProto.
 * MadelineProto is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * MadelineProto is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU General Public License along with MadelineProto.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * @author    Daniil Gentili <daniil@daniil.it>
 * @copyright 2016-2019 Daniil Gentili <daniil@daniil.it>
 * @license   https://opensource.org/licenses/AGPL-3.0 AGPLv3
 *
 * @link      https://docs.madelineproto.xyz MadelineProto documentation
 */

namespace danog\MadelineProto\Loop\Generic;

use danog\MadelineProto\Loop\Impl\ResumableSignalLoop;
use danog\MadelineProto\MTProto;

/**
 * Periodic loop.
 *
 * @author Daniil Gentili <daniil@daniil.it>
 */
class PeriodicLoop extends ResumableSignalLoop
{
    private $callback;
    private $name;
    private $timeout;

    /**
     * Constructor.
     *
     * @param \danog\MadelineProto\MTProto $API      Instance of MTProto class
     * @param callable                     $callback Callback to call
     * @param string                       $name     Loop name
     * @param int                          $timeout  Loop timeout
     */
    public function __construct(MTProto $API, $callback, string $name, $timeout)
    {
        $this->API = $API;
        $this->callback = $callback;
        $this->name = $name;
        $this->timeout = $timeout;
    }

    public function loop()
    {
        $callback = $this->callback;
        $logger = $this->API->logger;

        while (true) {
            $result = yield $this->waitSignal($this->pause($this->timeout));
            if ($result) {
                $logger->logger("Got signal in $this, exiting");
                return;
            }
            yield $callback();
        }
    }

    public function __toString(): string
    {
        return $this->name;
    }
}
